@@ -31,9 +31,12 @@ function(foltime, anc.ev, beta0.ev, anc.cens, beta0.cens, z=NA, beta=0, eff=0,
   sum2     <- 0
   start[j] <- 0
   stop2[j] <- 0
-  if (!is.na(z[1]) && z[1] == "unif")   az1 <- runif(1, as.numeric(z[2]), as.numeric(z[3]))
-  if (!is.na(z[1]) && z[1] == "normal") az1 <- rnorm(1, as.numeric(z[2]), as.numeric(z[3]))
-  if (is.na(z[1]))                      az1 <- 1
+  if (!is.na(z[1]) && z[1] == "gamma")    az1 <- rgamma(1, as.numeric(z[2]), as.numeric(z[3]))
+  if (!is.na(z[1]) && z[1] == "exp")      az1 <- rgamma(1, 1, as.numeric(z[2]))
+  if (!is.na(z[1]) && z[1] == "weibull")  az1 <- rweibull(1, as.numeric(z[2]), as.numeric(z[3]))
+  if (!is.na(z[1]) && z[1] == "unif")     az1 <- runif(1, as.numeric(z[2]), as.numeric(z[3]))
+  if (!is.na(z[1]) && z[1] == "invgauss") az1 <- rinvgauss(1, as.numeric(z[2]), as.numeric(z[3]))
+  if (is.na(z[1]))                        az1 <- 1
   while ((it[j-1] == 1 || j == 1) && (stop2[j-1] < foltime || j == 1) && j <= max.ep)
   {  
     k.ev       <- j
